.. emoji-data documentation master file, created by
   sphinx-quickstart on Wed Jan  9 13:52:44 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to emoji-data's documentation!
======================================

:Release: |release|
:Version: |version|
:Date:    |today|

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
